<?php

namespace Drupal\Tests\salesforce_mfw\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests the Salesforce MFW Configuration form.
 *
 * @group salesforce_mfw
 */
class SalesforceMFWConfigurationFormTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['salesforce_mfw'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the Salesforce MFW Configuration form submission.
   */
  public function testSalesforceMfwConfigurationForm() {
    $admin_user = $this->drupalCreateUser([
      'administer salesforce_mfw configuration',
    ]);
    $this->drupalLogin($admin_user);
    $this->drupalGet(Url::fromRoute('salesforce_mfw_configuration.settings'));
    $this->assertSession()->statusCodeEquals(200);

    $edit = [
      'allowed_paths' => '/path1\n/path2',
      'allow_path_override' => TRUE,
      'organization_id' => 'test_organization_id',
      'config_name' => 'test_config',
      'site_url' => 'https://example.com',
      'snippet_config' => 'https://example.com/snippet',
      'utility_bootstrap' => 'https://example.com/bootstrap',
      'language' => 'en_US',
    ];

    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->config('salesforce_mfw.settings')
      ->set('allowed_paths', $edit['allowed_paths'])
      ->set('allow_path_override', $edit['allow_path_override'])
      ->set('organization_id', $edit['organization_id'])
      ->set('config_name', $edit['config_name'])
      ->set('site_url', $edit['site_url'])
      ->set('snippet_config', $edit['snippet_config'])
      ->set('utility_bootstrap', $edit['utility_bootstrap'])
      ->set('language', $edit['language'])
      ->save();

    // Verify the saved configuration values using the configuration API.
    $config = \Drupal::config('salesforce_mfw.settings');
    $this->assertEquals($edit['allowed_paths'], $config->get('allowed_paths'));
    $this->assertEquals($edit['allow_path_override'], $config->get('allow_path_override'));
    $this->assertEquals($edit['organization_id'], $config->get('organization_id'));
    $this->assertEquals($edit['config_name'], $config->get('config_name'));
    $this->assertEquals($edit['site_url'], $config->get('site_url'));
    $this->assertEquals($edit['snippet_config'], $config->get('snippet_config'));
    $this->assertEquals($edit['utility_bootstrap'], $config->get('utility_bootstrap'));
    $this->assertEquals($edit['language'], $config->get('language'));

  }

  /**
   * Tests the Salesforce MFW Configuration permission access.
   */
  public function testSalesforcemfwConfigurationFormAccess() {
    // Create a user without necessary permissions.
    $admin_user = $this->drupalCreateUser();
    $this->drupalLogin($admin_user);
    $this->drupalGet(Url::fromRoute('salesforce_mfw_configuration.settings'));
    $this->assertSession()->statusCodeEquals(403);
  }

}
